@@ -9,18 +9,19 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.32_06';
+$VERSION = '0.32_07';
 
 %EXPORT_TAGS = (
     'all' => [qw(
         &clear &compare &copy &generate &generate_random &generate_time
-        &generate_v1 &generate_v4 &generate_v6 &is_null &parse &time
-        &type &unparse &unparse_lower &unparse_upper &uuid &uuid1 &uuid4
-        &uuid6 &variant
+        &generate_v0 &generate_v1 &generate_v4 &generate_v6 &generate_v7
+        &is_null &parse &time &type &unparse &unparse_lower
+        &unparse_upper &uuid &uuid0 &uuid1 &uuid4 &uuid6 &uuid7 &variant
+        &version
     )],
 );
 
-@EXPORT_OK = ( @{$EXPORT_TAGS{'all'}}, '&randnext' );
+@EXPORT_OK = @{$EXPORT_TAGS{'all'}};
 
 bootstrap UUID $VERSION;
 
@@ -65,10 +66,14 @@ UUID - Universally Unique Identifier library for Perl
     $str = uuid();                    # new stringified UUID; prefer v4
     $str = uuid1();                   # new stringified UUID; always v1
     $str = uuid4();                   # new stringified UUID; always v4
+    $str = uuid6();                   # new stringified UUID; always v6
+    $str = uuid7();                   # new stringified UUID; always v7
 
     UUID::generate($bin);             # new binary UUID; prefer v4
     UUID::generate_v1($bin);          # new binary UUID; always v1
     UUID::generate_v4($bin);          # new binary UUID; always v4
+    UUID::generate_v6($bin);          # new binary UUID; always v6
+    UUID::generate_v7($bin);          # new binary UUID; always v7
 
     UUID::generate_time($bin);        # alias for generate_v1()
     UUID::generate_random($bin);      # alias for generate_v4()
@@ -88,6 +93,7 @@ UUID - Universally Unique Identifier library for Perl
     UUID::time($bin);                 # return UUID time
     UUID::type($bin);                 # return UUID type
     UUID::variant($bin);              # return UUID variant
+    UUID::version($bin);              # return UUID version
 
 
 =head1 DESCRIPTION
@@ -274,6 +280,10 @@ Known variants:
     2  Microsoft
     3  Other
 
+=head2 B<version(> I<$uuid>> B<)>
+
+Alias for B<type()>.
+
 =head1 MAINTAINING STATE
 
 Internal state is optionally maintained for version 1 UUIDs via a file
