@@ -69,19 +69,17 @@ sub generate_conf {
             HAVE_WINDOWS_H       Windows.h
         ));
 
-        try_getentropy   ($check, \$longest, $defines);
-        try_getrandom    ($check, \$longest, $defines);
-        try_lstat        ($check, \$longest, $defines);
-        try_symlink      ($check, \$longest, $defines);
-
-        try_sa_len       ($check, \$longest, $defines);
-
         # win32 native if on windows but not under some
         # sort of unix environ. i.e. native.
-        # sets $WIN32.
+        # sets $WIN32. do this first.
         try_win32_native ($check, \$longest, $defines);
 
-        # requires $WIN32.
+        #try_getentropy   ($check, \$longest, $defines);
+        #try_getrandom    ($check, \$longest, $defines);
+        try_lstat        ($check, \$longest, $defines);
+        try_precise      ($check, \$longest, $defines);
+        try_sa_len       ($check, \$longest, $defines);
+        try_symlink      ($check, \$longest, $defines);
         try_threads      ($check, \$longest, $defines);
 
         # do this last, just to be safe.
@@ -411,6 +409,38 @@ sub try_threads {
     unlink $conf1, $conf2;
 }
 
+sub try_precise {
+    my ($check, $long, $defs) = @_;
+    my $msg = 'Checking precise systime';
+    my $len = length $msg;
+    if ($check) { $$long = $len if $len > $$long; return; }
+    my $more = $$long - $len;
+    my $conf = gen_confh($defs);
+
+    my $Werror = $WIN32 ? '-WX'  : '-Werror';
+    my $lib    = $WIN32 ? 'ucrt' : 'c';
+
+    if ( check_lib(
+        header   => $conf,
+        lib      => $lib,
+        ccflags  => "-I. $Werror",
+        debug    => 0,
+        function => q{
+            FILETIME  file_time;
+            GetSystemTimePreciseAsFileTime( &file_time );
+            return 0;
+        },
+    )) {
+        push @$defs, '#define HAVE_PRECISE_SYSTIME 1';
+        print $msg, ' ..', '.'x$more, ' found';
+    }
+    else {
+        push @$defs, '#undef HAVE_PRECISE_SYSTIME';
+        print $msg, ' ..', '.'x$more, ' missing';
+    }
+    unlink $conf;
+}
+
 sub try_u64 {
     my ($check, $long, $defs) = @_;
     my $msg = 'Checking U64 type';
