@@ -41,11 +41,19 @@
 #define BUFSZ    16*CORESZ /* bytes we get at a time (1024) */
 #define ROUNDS   20
 
+#ifdef USE_WIN32_NATIVE
+typedef __declspec(align (8)) struct {
+#else
 typedef struct {
+#endif
   U32     state[STATESZ];
   UCHAR   buf[BUFSZ];
   U16     have;
+#ifdef USE_WIN32_NATIVE
 } cc_struct_t;
+#else
+} cc_struct_t __attribute__ ((aligned (8)));
+#endif
 
 static cc_struct_t cc;
 
@@ -112,8 +120,8 @@ static void cc_core(UCHAR* buf) {
   if (++s[12] == 0) s[13]++;
 }
 
-static U32 cc_stream(UCHAR* buf, IV n) {
-  IV    r = n;
+static U16 cc_stream(UCHAR* buf, U16 n) {
+  U16   r = n;
   UCHAR sbuf[CORESZ];
 
   while (r >= CORESZ) {
@@ -130,12 +138,11 @@ static U32 cc_stream(UCHAR* buf, IV n) {
 
 static U32 cc_refill() {
   U64   *cp;
-  UCHAR seed[40];
 
   /* refill buffer */
   cc.have = cc_stream((UCHAR*)&cc.buf, BUFSZ);
 
-  /* use the first KEYSZ bytes from buffer to re-init, then zero them */
+  /* reseed with KEYSZ bytes from buffer, then zero */
   /*
   cc_init(cc.buf, 0);
   memset(cc.buf, 0, KEYSZ);
@@ -144,6 +151,8 @@ static U32 cc_refill() {
   */
 
   /* create new key */
+  /*
+  UCHAR seed[40];
   cp = (U64*)&seed;
   *cp++ = xo_rand();
   *cp++ = xo_rand();
@@ -151,8 +160,21 @@ static U32 cc_refill() {
   *cp++ = xo_rand();
   *cp++ = xo_rand();
   cc_init((UCHAR*)&seed, 0);
-  cc.have = BUFSZ;
+  return cc.have;
+  */
 
+  /* salt the state */
+  /*
+  cp = (U64*)&cc.state;
+  while (cp < (U64*)&cc.buf)
+    *cp++ ^= (U32)xo_rand();
+  return cc.have;
+  */
+
+  /* salt the buffer */
+  cp = (U64*)&cc.buf;
+  while (cp < (U64*)&cc.have)
+    *cp++ ^= xo_rand();
   return cc.have;
 }
 
