@@ -3,7 +3,7 @@
 
 #include "uulib/CONF.h"
 
-void cc_seed(const UCHAR *data, UV nbytes);
+void cc_srand(void);
 
 void cc_rand16(U16 *out);
 void cc_rand32(U32 *out);
