@@ -9,18 +9,24 @@
 #endif
 #undef open
 
+static int        state_fd = -2;
+static FILE       *state_f = NULL;
 static const char *statepath = NULL;
 
 void uu_init_statepath(const char *path) {
+  if (state_fd >= 0)
+    fclose(state_f);
+  state_fd  = -2;
   statepath = path;
 }
 
-
+/* returns 100ns intervals since unix epoch.
+*  since gettimeofday() is in 1usec intervals,
+*  last digit is simulated via adjustment.
+*/
 IV uu_clock(U64 *clock_reg, U16 *ret_clock_seq) {
   static int            adjustment = 0;
   static struct timeval last = {0, 0};
-  static int            state_fd = -2;
-  static FILE           *state_f;
   static U16            clock_seq;
   struct timeval        tv;
   struct stat           statbuf;
@@ -65,7 +71,7 @@ IV uu_clock(U64 *clock_reg, U16 *ret_clock_seq) {
 
     if (fscanf(state_f, "clock: %04x tv: %lu %lu adj: %d\n",
          &cl, &tv1, &tv2, &a) == 4) {
-      clock_seq = cl & 0x3FFF;
+      clock_seq = cl & 0x3fff;
       last.tv_sec = tv1;
       last.tv_usec = tv2;
       adjustment = a;
@@ -74,20 +80,20 @@ IV uu_clock(U64 *clock_reg, U16 *ret_clock_seq) {
 
   if ((last.tv_sec == 0) && (last.tv_usec == 0)) {
     cc_rand16(&clock_seq);
-    clock_seq &= 0x3FFF;
+    clock_seq &= 0x3fff;
     gettimeofday(&last, 0);
     last.tv_sec--;
   }
 
   gettimeofday(&tv, 0);
   if ((tv.tv_sec < last.tv_sec) || ((tv.tv_sec == last.tv_sec) && (tv.tv_usec < last.tv_usec))) {
-    clock_seq = (clock_seq+1) & 0x3FFF;
+    clock_seq = (clock_seq+1) & 0x3fff;
     adjustment = 0;
     last = tv;
   }
   else if ((tv.tv_sec == last.tv_sec) && (tv.tv_usec == last.tv_usec)) {
     if (adjustment >= MAX_ADJUSTMENT) {
-      clock_seq = (clock_seq+1) & 0x3FFF;
+      clock_seq = (clock_seq+1) & 0x3fff;
       adjustment = 0;
     }
     else {
@@ -101,7 +107,7 @@ IV uu_clock(U64 *clock_reg, U16 *ret_clock_seq) {
 
   *clock_reg = tv.tv_usec*10 + adjustment;
   *clock_reg += ((U64)tv.tv_sec)*10000000;
-  *clock_reg += (((U64)0x01B21DD2) << 32) + 0x13814000;
+  /* *clock_reg += (((U64)0x01b21dd2) << 32) + 0x13814000; */
 
   if (state_fd > 0) {
     rewind(state_f);
