@@ -1,7 +1,7 @@
 #include "uulib/gettime.h"
 
 #ifdef USE_WIN32_NATIVE
-int gettimeofday(struct timeval * tp, struct timezone * tzp) {
+int gettimeofday(struct timeval * tv, struct timezone * tz) {
   /* Note: SYSTEMTIME has 1ms resolution.
   *       FILETIME has 100nsec resolution.
   *       struct timeval has 1usec resolution.
@@ -16,12 +16,16 @@ int gettimeofday(struct timeval * tp, struct timezone * tzp) {
   FILETIME  file_time;
   U64       time;
 
+#ifdef HAVE_PRECISE_SYSTIME
+  GetSystemTimePreciseAsFileTime( &file_time );
+#else
   GetSystemTimeAsFileTime( &file_time );
+#endif
   time =  ((U64)file_time.dwLowDateTime )      ;
   time += ((U64)file_time.dwHighDateTime) << 32;
 
-  tp->tv_sec  = (long)((time - EPOCH) / 10000000L);
-  tp->tv_usec = (long)(((time - EPOCH) % 10000000L) / 10);
+  tv->tv_sec  = (long)((time - EPOCH) / 10000000L);
+  tv->tv_usec = (long)(((time - EPOCH) % 10000000L) / 10);
   return 0;
 }
 #endif /* USE_WIN32_NATIVE */
