@@ -6,7 +6,7 @@
 #ifdef USE_WIN32_NATIVE
 #ifndef HAVE_GETTIMEOFDAY
 #define HAVE_GETTIMEOFDAY
-int gettimeofday(struct timeval * tp, struct timezone * tzp);
+int gettimeofday(struct timeval * tv, struct timezone * tz);
 #endif /* HAVE_GETTIMEOFDAY */
 #endif /* USE_WIN32_NATIVE */
 
