@@ -11,9 +11,13 @@ void sm_srand() {
   struct timeval  tv;
   int             i, n;
 
-  sm_x = gt_100ns64();
-
   gettimeofday(&tv, 0);
+
+  sm_x = gt_100ns64()
+    ^ (U64)tv.tv_sec  << 16
+    ^ (U64)tv.tv_usec << 32
+    ^ (U64)getpid()   << 48;
+
   n = (tv.tv_sec ^ tv.tv_usec) & 0x1f;
 
   for (i=0; i<n; ++i)
